@@ -198,21 +198,21 @@ Naryn::~Naryn()
 string Naryn::get_shm_sem_name()
 {
 	char buf[100];
-	sprintf(buf, "/naryn_shm_sem_%d", (int)getpid());
+	snprintf(buf, sizeof(buf), "/naryn_shm_sem_%d", (int)getpid());
 	return buf;
 }
 
 string Naryn::get_fifo_sem_name()
 {
 	char buf[100];
-	sprintf(buf, "/naryn_fifo_sem_%d", (int)getpid());
+	snprintf(buf, sizeof(buf), "/naryn_fifo_sem_%d", (int)getpid());
 	return buf;
 }
 
 string Naryn::get_fifo_name()
 {
 	char buf[100];
-    sprintf(buf, "/tmp/naryn_fifo_%d", s_is_kid ? (int)getppid() : (int)getpid());
+    snprintf(buf, sizeof(buf), "/tmp/naryn_fifo_%d", s_is_kid ? (int)getppid() : (int)getpid());
 	return buf;
 }
 
@@ -652,8 +652,9 @@ void verror(const char *fmt, ...)
 	char buf[1000];
 
     buf[0] = '\0';
-    if (g_naryn->debug())
-        sprintf(buf, "[pid %d] ", (int)getpid());
+    if (g_naryn->debug()) {
+        snprintf(buf, sizeof(buf), "[pid %d] ", (int)getpid());
+    }
 
 	va_start(ap, fmt);
 	vsnprintf(buf + strlen(buf), sizeof(buf), fmt, ap);
@@ -689,8 +690,11 @@ void vdebug(const char *fmt, ...)
         REprintf("[DEBUG pid %d, %s.%03d] ", (int)getpid(), buf, (int)(tmnow.tv_usec / 1000));
 
         va_list ap;
-    	va_start(ap, fmt);
-        vsnprintf(buf, sizeof(buf), fmt, ap);    	
+    	va_start(ap, fmt);        
+        int ret = vsnprintf(buf, sizeof(buf), fmt, ap);
+        if (ret < 0){
+            TGLError("null format string");
+        }
         va_end(ap);
         REprintf(buf);
 
